Authors
*******


Lead
====

- Derrick Gilland, dgilland@gmail.com, `dgilland@github <https://github.com/dgilland>`_


Contributors
============

- Nathan Cahill, nathan@nathancahill.com, `nathancahill@github <https://github.com/nathancahill>`_
- Klaus Sevensleeper, k7sleeper@gmail.com, `k7sleeper@github <https://github.com/k7sleeper>`_
- Michael James, `urbnjamesmi1 <https://github.com/urbnjamesmi1>`_
